@@ -604,6 +604,12 @@ mfxStatus EncTools::Query(mfxEncToolsTaskParam* par, mfxU32 /*timeOut*/)
         sts = m_brc.ProcessFrame(par->DisplayOrder, pFrameQp);
         MFX_CHECK_STS(sts);
     }
+    mfxEncToolsBRCHRDPos *pHRDPos = (mfxEncToolsBRCHRDPos *)Et_GetExtBuffer(par->ExtParam, par->NumExtParam, MFX_EXTBUFF_ENCTOOLS_BRC_HRD_POS);
+    if (pHRDPos && IsOn(m_config.BRC))
+    {
+        sts = m_brc.GetHRDPos(par->DisplayOrder, pHRDPos);
+        MFX_CHECK_STS(sts);
+    }
 
     return sts;
 }
