@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2018 Intel Corporation
+// Copyright (c) 2017-2019 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -78,7 +78,7 @@ mfxStatus MFXVP9DecoderPlugin::GetPluginParam(mfxPluginParam* par)
 
 mfxStatus MFXVP9DecoderPlugin::CreateByDispatcher(mfxPluginUID guid, mfxPlugin* mfxPlg)
 {
-    if (memcmp(& guid , &g_VP9DecoderGuid, sizeof(mfxPluginUID))) {
+    if (guid != g_VP9DecoderGuid) {
         return MFX_ERR_NOT_FOUND;
     }
 
