@@ -23,6 +23,7 @@
 #if defined (MFX_ENABLE_VPP)
 #if defined (MFX_VA_LINUX)
 
+#include "mfx_session.h"
 #include <math.h>
 #include "mfx_vpp_defs.h"
 #include "mfx_vpp_vaapi.h"
@@ -87,11 +88,13 @@ VAAPIVideoProcessing::VAAPIVideoProcessing():
 , m_deintFilterID(VA_INVALID_ID)
 , m_procampFilterID(VA_INVALID_ID)
 , m_frcFilterID(VA_INVALID_ID)
+, m_gpuPriorityID(VA_INVALID_ID)
 , m_deintFrameCount(0)
 #ifdef MFX_ENABLE_VPP_FRC
 , m_frcCyclicCounter(0)
 #endif
 , m_numFilterBufs(0)
+, m_MaxContextPriority(0)
 , m_primarySurface4Composition(NULL)
 {
 
@@ -236,7 +239,7 @@ mfxStatus VAAPIVideoProcessing::Init(_mfxPlatformAccelerationService* pVADisplay
                                             VAProfileNone,
                                             va_entrypoints,
                                             &entrypointsCount);
-        MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+        MFX_CHECK(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
 
         for( entrypointsIndx = 0; entrypointsIndx < entrypointsCount; entrypointsIndx++ )
         {
@@ -259,7 +262,7 @@ mfxStatus VAAPIVideoProcessing::Init(_mfxPlatformAccelerationService* pVADisplay
                                 NULL,
                                 0,
                                 &m_vaConfig);
-        MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+        MFX_CHECK(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
 
         // Context
         int width = pParams->vpp.Out.Width;
@@ -275,7 +278,7 @@ mfxStatus VAAPIVideoProcessing::Init(_mfxPlatformAccelerationService* pVADisplay
                                     0, 0,
                                     &m_vaContextVPP);
         }
-        MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+        MFX_CHECK(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
     }
 
     return MFX_ERR_NONE;
@@ -300,35 +303,35 @@ mfxStatus VAAPIVideoProcessing::QueryCapabilities(mfxVppCaps& caps)
     mfxU32 num_filters = VAProcFilterCount;
 
     vaSts = vaQueryVideoProcFilters(m_vaDisplay, m_vaContextVPP, filters, &num_filters);
-    MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+    MFX_CHECK(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
 
     mfxU32 num_procamp_caps = VAProcColorBalanceCount;
     vaSts = vaQueryVideoProcFilterCaps(m_vaDisplay,
                                m_vaContextVPP,
                                VAProcFilterColorBalance,
                                &m_procampCaps, &num_procamp_caps);
-    MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+    MFX_CHECK(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
 
     mfxU32 num_denoise_caps = 1;
     vaSts = vaQueryVideoProcFilterCaps(m_vaDisplay,
                                m_vaContextVPP,
                                VAProcFilterNoiseReduction,
                                &m_denoiseCaps, &num_denoise_caps);
-    MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+    MFX_CHECK(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
 
     mfxU32 num_detail_caps = 1;
     vaSts = vaQueryVideoProcFilterCaps(m_vaDisplay,
                                m_vaContextVPP,
                                VAProcFilterSharpening,
                                &m_detailCaps, &num_detail_caps);
-    MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+    MFX_CHECK(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
 
     mfxU32 num_deinterlacing_caps = VAProcDeinterlacingCount;
     vaSts = vaQueryVideoProcFilterCaps(m_vaDisplay,
                                m_vaContextVPP,
                                VAProcFilterDeinterlacing,
                                &m_deinterlacingCaps, &num_deinterlacing_caps);
-    MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+    MFX_CHECK(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
 
 #ifdef MFX_ENABLE_VPP_FRC
     /* to check is FRC enabled or not*/
@@ -341,7 +344,7 @@ mfxStatus VAAPIVideoProcessing::QueryCapabilities(mfxVppCaps& caps)
                                m_vaContextVPP,
                                VAProcFilterFrameRateConversion,
                                &tempFRC_Caps, &num_frc_caps);
-    MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+    MFX_CHECK(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
 
     if (0 != tempFRC_Caps.frc_custom_rates) /* FRC is enabled, at least one mode */
     {
@@ -362,7 +365,7 @@ mfxStatus VAAPIVideoProcessing::QueryCapabilities(mfxVppCaps& caps)
                                                 m_vaContextVPP,
                                                 VAProcFilterFrameRateConversion,
                                                 &m_frcCaps[ii], &num_frc_caps);
-            MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+            MFX_CHECK(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
             caps.frcCaps.customRateData[ii].inputFramesOrFieldPerCycle = m_frcCaps[ii].input_frames;
             caps.frcCaps.customRateData[ii].outputIndexCountPerCycle = m_frcCaps[ii].output_frames;
             /* out frame rate*/
@@ -412,7 +415,7 @@ mfxStatus VAAPIVideoProcessing::QueryCapabilities(mfxVppCaps& caps)
                                  0,
                                  &m_pipelineCaps);
 #ifdef MFX_ENABLE_VPP_ROTATION
-    MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+    MFX_CHECK(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
     if (m_pipelineCaps.rotation_flags & (1 << VA_ROTATION_90 ) &&
         m_pipelineCaps.rotation_flags & (1 << VA_ROTATION_180) &&
         m_pipelineCaps.rotation_flags & (1 << VA_ROTATION_270))
@@ -469,6 +472,8 @@ mfxStatus VAAPIVideoProcessing::QueryCapabilities(mfxVppCaps& caps)
         case MFX_FOURCC_Y416:
 #endif
         case MFX_FOURCC_P010:
+        // A2RGB10 supported as input in case of passthru copy
+        case MFX_FOURCC_A2RGB10:
             caps.mFormatSupport[fourcc] |= MFX_FORMAT_SUPPORT_INPUT;
             break;
         default:
@@ -513,6 +518,17 @@ mfxStatus VAAPIVideoProcessing::QueryCapabilities(mfxVppCaps& caps)
         caps.uChromaSiting = m_core->GetHWType() >= MFX_HW_SCL ? 1 : 0;
     }
 
+    std::vector<VAConfigAttrib> attrib(1);
+    attrib[0].type = VAConfigAttribContextPriority;
+    vaSts = vaGetConfigAttributes(m_vaDisplay,
+                                  VAProfileNone,
+                                  VAEntrypointVideoProc,
+                                  attrib.data(),
+                                  attrib.size());
+    MFX_CHECK(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+    if (attrib[0].value != VA_ATTRIB_NOT_SUPPORTED)
+        m_MaxContextPriority = attrib[0].value;
+
     return MFX_ERR_NONE;
 
 } // mfxStatus VAAPIVideoProcessing::QueryCapabilities(mfxVppCaps& caps)
@@ -616,21 +632,18 @@ mfxStatus VAAPIVideoProcessing::Execute(mfxExecuteParams *pParams)
              * are fed into de-interlacer.
              **/
 
-            // ADI 30i->30p: To get first field of current frame , set deint.flags second output field.
+            /* ADI 30i->30p: To get first field of current frame only
+             * For TFF cases, deint.flags required to set VA_DEINTERLACING_ONE_FIELD
+             * ensure driver go 30i->30p mode and surface set correct
+             * For BFF cases, deint.flags required to set all bits
+             * ensure driver go 30i->30p mode and surface set correct
+             **/
             if(deint.algorithm == VAProcDeinterlacingMotionAdaptive && (pParams->refCount > 1))
             {
                 if (MFX_PICSTRUCT_FIELD_TFF & pCurSurf_frameInfo->frameInfo.PicStruct)
-                    deint.flags = VA_DEINTERLACING_BOTTOM_FIELD;
-                else /* For BFF, second field is Top */
-                    deint.flags = VA_DEINTERLACING_BOTTOM_FIELD_FIRST;
-
-                if (MFX_HW_APL == hwType)
-                {
-                    if (MFX_PICSTRUCT_FIELD_TFF & pCurSurf_frameInfo->frameInfo.PicStruct)
-                        deint.flags = VA_DEINTERLACING_ONE_FIELD;
-                    else /* For BFF case required to set all bits  */
-                        deint.flags = VA_DEINTERLACING_BOTTOM_FIELD_FIRST | VA_DEINTERLACING_BOTTOM_FIELD | VA_DEINTERLACING_ONE_FIELD;
-                }
+                    deint.flags = VA_DEINTERLACING_ONE_FIELD;
+                else /* For BFF case required to set all bits  */
+                    deint.flags = VA_DEINTERLACING_BOTTOM_FIELD_FIRST | VA_DEINTERLACING_BOTTOM_FIELD | VA_DEINTERLACING_ONE_FIELD;
             }
 
             /* For 30i->60p case we have to indicate
@@ -1138,6 +1151,16 @@ mfxStatus VAAPIVideoProcessing::Execute(mfxExecuteParams *pParams)
         ENABLE_VPP_VIDEO_SIGNAL(m_pipelineParam[0].output_color_properties.color_range = VA_SOURCE_RANGE_FULL);
         break;
     case MFX_FOURCC_NV12:
+        m_pipelineParam[0].output_color_standard = VAProcColorStandardBT601;
+        if(refFourcc == MFX_FOURCC_RGBP)
+        {
+            ENABLE_VPP_VIDEO_SIGNAL(m_pipelineParam[0].output_color_properties.color_range = VA_SOURCE_RANGE_FULL);
+        }
+        else
+        {
+            ENABLE_VPP_VIDEO_SIGNAL(m_pipelineParam[0].output_color_properties.color_range = VA_SOURCE_RANGE_REDUCED);
+        }
+        break;
     default:
         m_pipelineParam[0].output_color_standard = VAProcColorStandardBT601;
         ENABLE_VPP_VIDEO_SIGNAL(m_pipelineParam[0].output_color_properties.color_range = VA_SOURCE_RANGE_REDUCED);
@@ -1330,6 +1353,35 @@ if (pParams->mirroringExt)
 
     VASurfaceID *outputSurface = (VASurfaceID*)(pParams->targetSurface.hdl.first);
 
+    //create gpu priority buffer and bufferID
+    if(m_MaxContextPriority)
+    {
+        mfxPriority contextPriority = m_core->GetSession()->m_priority;
+        VAContextParameterUpdateBuffer GpuPriorityBuf_vpp;
+        memset(&GpuPriorityBuf_vpp, 0, sizeof(VAContextParameterUpdateBuffer));
+
+        GpuPriorityBuf_vpp.flags.bits.context_priority_update = 1;
+        if(contextPriority == MFX_PRIORITY_LOW)
+        {
+            GpuPriorityBuf_vpp.context_priority.bits.priority = 0;
+        }
+        else if (contextPriority == MFX_PRIORITY_HIGH)
+        {
+            GpuPriorityBuf_vpp.context_priority.bits.priority = m_MaxContextPriority;
+        }
+        else
+        {
+            GpuPriorityBuf_vpp.context_priority.bits.priority = m_MaxContextPriority/2;
+        }
+
+        vaSts = vaCreateBuffer((void*)m_vaDisplay,
+                            m_vaContextVPP,
+                            VAContextParameterUpdateBufferType,
+                            sizeof(GpuPriorityBuf_vpp), 1,
+                            &GpuPriorityBuf_vpp, &m_gpuPriorityID);
+        MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+    }
+
     MFX_LTRACE_2(MFX_TRACE_LEVEL_HOTSPOTS, "A|VPP|FILTER|PACKET_START|", "%d|%d", m_vaContextVPP, 0);
     {
         MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaBeginPicture");
@@ -1339,6 +1391,13 @@ if (pParams->mirroringExt)
         MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
     }
 
+    if(m_MaxContextPriority)
+    {
+        MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaRenderPicture_gpuPriority");
+        vaSts = vaRenderPicture(m_vaDisplay, m_vaContextVPP, &m_gpuPriorityID, 1);
+        MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+    }
+
     {
         MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaRenderPicture");
         vaSts = vaRenderPicture(m_vaDisplay, m_vaContextVPP, &m_pipelineParamID[0], 1);
@@ -1358,6 +1417,12 @@ if (pParams->mirroringExt)
         MFX_CHECK_STS(mfxSts);
     }
 
+    if(m_MaxContextPriority)
+    {
+        mfxSts = CheckAndDestroyVAbuffer(m_vaDisplay, m_gpuPriorityID);
+        MFX_CHECK_STS(mfxSts);
+    }
+
     mfxSts = RemoveBufferFromPipe(m_deintFilterID);
     MFX_CHECK_STS(mfxSts);
 
@@ -1687,7 +1752,7 @@ mfxStatus VAAPIVideoProcessing::Execute_Composition_TiledVideoWall(mfxExecutePar
 
         m_pipelineParam[i].filters      = 0;
         m_pipelineParam[i].num_filters  = 0;
-        m_pipelineParam[i].output_background_color = 0;
+        m_pipelineParam[i].output_background_color = 0xff000000;
 
         vaSts = vaCreateBuffer(m_vaDisplay,
                             m_vaContextVPP,
@@ -2389,7 +2454,7 @@ mfxStatus VAAPIVideoProcessing::QueryTaskStatus(mfxU32 taskIndex)
         if (vaSts == VA_STATUS_ERROR_HW_BUSY)
             return MFX_ERR_GPU_HANG;
         else
-            MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+            MFX_CHECK(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
     }
 #endif
 
