@@ -731,6 +731,8 @@ void PackerVA::PackProcessingInfo(H264DecoderFrameInfo * sliceInfo)
 
     pipelineBuf->surface = m_va->GetSurfaceID(sliceInfo->m_pFrame->m_index); // should filled in packer
     pipelineBuf->additional_outputs = (VASurfaceID*)vpVA->GetCurrentOutputSurface();
+    // To keep output aligned, decode downsampling use this fixed combination of chroma sitting type
+    pipelineBuf->input_color_properties.chroma_sample_location = VA_CHROMA_SITING_HORIZONTAL_LEFT | VA_CHROMA_SITING_VERTICAL_CENTER;
 }
 
 void PackerVA::PackQmatrix(const UMC_H264_DECODER::H264ScalingPicParams * scaling)
