@@ -325,7 +325,7 @@ private:
 
             if (zeroCount >= 2 && pb[0] == 1)
             {
-                startCodeSize = MFX_MIN(zeroCount + 1, 4);
+                startCodeSize = std::min(zeroCount + 1, 4u);
                 size -= i + 1;
                 pb++; // remove 0x01 symbol
                 if (size >= 1)
@@ -358,7 +358,7 @@ private:
             }
         }
 
-        zeroCount = MFX_MIN(zeroCount, 3);
+        zeroCount = std::min(zeroCount, 3u);
         pb -= zeroCount;
         size = zeroCount;
         startCodeSize = zeroCount;
@@ -386,7 +386,7 @@ public:
                     pRemovedOffsets);
 
         VM_ASSERT(pMemDst->GetSize() >= dstSize);
-        size_t tail_size = MFX_MIN(pMemDst->GetSize() - dstSize, DEFAULT_NU_TAIL_SIZE);
+        size_t tail_size = std::min<size_t>(pMemDst->GetSize() - dstSize, DEFAULT_NU_TAIL_SIZE);
         memset(pMemDst->GetPointer() + dstSize, DEFAULT_NU_TAIL_VALUE, tail_size);
         pMemDst->SetDataSize(dstSize);
         pMemDst->SetTime(pMemSrc->GetTime());
@@ -597,7 +597,7 @@ void SwapMemoryAndRemovePreventingBytes_H265(void *pDestination, size_t &nDstSiz
 
     // first two bytes
     i = 0;
-    while (i < (uint32_t) MFX_MIN(2, nSrcSize))
+    while (i < std::min<uint32_t>(2, nSrcSize))
     {
         pDst = (uint8_t) pSrc;
         ++pDst;
