@@ -104,7 +104,7 @@ void MJPEGVideoDecoderBaseMFX::AdjustFrameSize(mfxSize & size)
     size.height = mfx::align2_value(size.height, m_interleaved ? 32 : 16);
 }
 
-ChromaType MJPEGVideoDecoderBaseMFX::GetChromaType()
+std::pair<ChromaType, Status> MJPEGVideoDecoderBaseMFX::GetChromaType()
 {
 /*
  0:YUV400 (grayscale image) Y: h=1 v=1,
@@ -119,7 +119,7 @@ ChromaType MJPEGVideoDecoderBaseMFX::GetChromaType()
 
     if (m_decBase->m_jpeg_ncomp == 1)
     {
-        return CHROMA_TYPE_YUV400;
+        return { CHROMA_TYPE_YUV400, UMC_OK };
     }
 
     ChromaType type = CHROMA_TYPE_YUV400;
@@ -133,23 +133,32 @@ ChromaType MJPEGVideoDecoderBaseMFX::GetChromaType()
             else if (m_decBase->m_jpeg_color == JC_RGB)
                 type = CHROMA_TYPE_RGB;
             else
-                VM_ASSERT(false);
+                return { CHROMA_TYPE_YUV400, UMC_ERR_UNSUPPORTED };
         }
         else
         {
-            VM_ASSERT((m_decBase->m_ccomp[0].m_vsampling == 2) && (m_decBase->m_ccomp[1].m_hsampling == 1));
+            if (m_decBase->m_ccomp[0].m_vsampling != 2 || m_decBase->m_ccomp[1].m_hsampling != 1)
+            {
+                return { CHROMA_TYPE_YUV400, UMC_ERR_UNSUPPORTED };
+            }
             type = CHROMA_TYPE_YUV422V_2Y; // YUV422V_2Y
         }
         break;
     case 2: // YUV420, YUV422H_2Y, YUV422H_4Y, YUV422V_4Y
         if (m_decBase->m_ccomp[0].m_vsampling == 1)
         {
-            VM_ASSERT(m_decBase->m_ccomp[1].m_vsampling == 1 && m_decBase->m_ccomp[1].m_hsampling == 1);
+            if ( m_decBase->m_ccomp[1].m_vsampling != 1 || m_decBase->m_ccomp[1].m_hsampling != 1)
+            {
+                return { CHROMA_TYPE_YUV400, UMC_ERR_UNSUPPORTED };
+            }
             type = CHROMA_TYPE_YUV422H_2Y; // YUV422H_2Y
         }
         else
         {
-            VM_ASSERT(m_decBase->m_ccomp[0].m_vsampling == 2);
+            if (m_decBase->m_ccomp[0].m_vsampling != 2)
+            {
+                return { CHROMA_TYPE_YUV400, UMC_ERR_UNSUPPORTED };
+            }
 
             if (m_decBase->m_ccomp[1].m_hsampling == 1 && m_decBase->m_ccomp[1].m_vsampling == 1)
                 type = CHROMA_TYPE_YUV420; // YUV420;
@@ -158,18 +167,20 @@ ChromaType MJPEGVideoDecoderBaseMFX::GetChromaType()
         }
         break;
     case 4: // YUV411
-        VM_ASSERT(m_decBase->m_ccomp[0].m_vsampling == 1);
+        if (m_decBase->m_ccomp[0].m_vsampling != 1)
+        {
+            return { CHROMA_TYPE_YUV400, UMC_ERR_UNSUPPORTED };
+        }
         type = CHROMA_TYPE_YUV411;
         break;
     default:
-        VM_ASSERT(false);
-        break;
+        return { CHROMA_TYPE_YUV400, UMC_ERR_UNSUPPORTED };
     }
 
-    return type;
+    return { type, UMC_OK };
 }
 
-JCOLOR MJPEGVideoDecoderBaseMFX::GetColorType()
+std::pair<JCOLOR, Status> MJPEGVideoDecoderBaseMFX::GetColorType()
 {
     JCOLOR color = JC_UNKNOWN;
     switch(m_decBase->m_jpeg_color)
@@ -187,11 +198,10 @@ JCOLOR MJPEGVideoDecoderBaseMFX::GetColorType()
         color = JC_RGB;
         break;
     default:
-        VM_ASSERT(false);
-        break;
+        return { JC_UNKNOWN, UMC_ERR_UNSUPPORTED };
     }
 
-    return color;
+    return { color, UMC_OK };
 }
 
 Status MJPEGVideoDecoderBaseMFX::FillVideoParam(mfxVideoParam *par, bool /*full*/)
@@ -228,8 +238,19 @@ Status MJPEGVideoDecoderBaseMFX::FillVideoParam(mfxVideoParam *par, bool /*full*
     par->mfx.CodecProfile = 1;
     par->mfx.CodecLevel = 1;
 
-    par->mfx.JPEGChromaFormat = GetMFXChromaFormat(GetChromaType());
-    par->mfx.JPEGColorFormat = GetMFXColorFormat(GetColorType());
+    std::pair<ChromaType, Status> chromaTypeRes = GetChromaType();
+    if (chromaTypeRes.second != UMC_OK)
+    {
+        return chromaTypeRes.second;
+    }
+    par->mfx.JPEGChromaFormat = GetMFXChromaFormat(chromaTypeRes.first);
+
+    std::pair<JCOLOR, Status> colorTypeRes = GetColorType();
+    if (colorTypeRes.second != UMC_OK)
+    {
+        return colorTypeRes.second;
+    }
+    par->mfx.JPEGColorFormat = GetMFXColorFormat(colorTypeRes.first);
     par->mfx.Rotation  = MFX_ROTATION_0;
     par->mfx.InterleavedDec = (mfxU16)(m_interleavedScan ? MFX_SCANTYPE_INTERLEAVED : MFX_SCANTYPE_NONINTERLEAVED);
 
