@@ -1,4 +1,4 @@
-// Copyright (c) 2017 Intel Corporation
+// Copyright (c) 2017-2019 Intel Corporation
 // 
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -387,7 +387,7 @@ namespace UMC
             slparams.MBStartRow = 0;
             slparams.MBEndRow = m_pContext->m_seqLayerHeader.heightMB;
             m_pContext->m_picLayerHeader->CurrField = 0;
-            if (m_pContext->m_picLayerHeader->PTYPE == VC1_SKIPPED_FRAME)
+            if (VC1_IS_SKIPPED(m_pContext->m_picLayerHeader->PTYPE))
             {
                 m_bIsSkippedFrame = true;
                 m_bIsReadyToProcess = false;
@@ -967,7 +967,7 @@ namespace UMC
                                          uint8_t*   pOriginalData,
                                          MediaDataEx::_MediaDataEx* pOrigStCodes)
         {
-            if (m_pContext->m_picLayerHeader->PTYPE == VC1_SKIPPED_FRAME)
+            if (VC1_IS_SKIPPED(m_pContext->m_picLayerHeader->PTYPE))
             {
                 m_bIsSkippedFrame = true;
                 m_bIsReadyToProcess = false;
@@ -1102,7 +1102,7 @@ namespace UMC
                                  uint8_t*   pOriginalData,
                                  MediaDataEx::_MediaDataEx* pOrigStCodes)
         {
-            if (this->m_pContext->m_picLayerHeader->PTYPE == VC1_SKIPPED_FRAME)
+            if (VC1_IS_SKIPPED(this->m_pContext->m_picLayerHeader->PTYPE))
             {
                 this->m_bIsSkippedFrame = true;
                 this->m_bIsReadyToProcess = false;
@@ -1135,7 +1135,6 @@ namespace UMC
             uint32_t SliceSize = 0;
             uint32_t DataSize = 0;
             uint32_t BitstreamDataSize = 0;
-            uint32_t IntCompField = 0;
 
             // need in case of fields
             uint32_t* pFirstFieldStartCode = this->m_pContext->m_bitstream.pBitstream;
@@ -1167,7 +1166,7 @@ namespace UMC
             slparams.MBEndRow = this->m_pContext->m_seqLayerHeader.heightMB;
             this->m_pContext->m_picLayerHeader->CurrField = 0;
 
-            if (this->m_pContext->m_picLayerHeader->PTYPE == VC1_SKIPPED_FRAME)
+            if (VC1_IS_SKIPPED(this->m_pContext->m_picLayerHeader->PTYPE))
             {
                 this->m_bIsSkippedFrame = true;
                 this->m_bIsReadyToProcess = false;
@@ -1195,7 +1194,6 @@ namespace UMC
                 DecodePicHeader(this->m_pContext);
             else
                 Decode_PictureLayer(this->m_pContext);
-            IntCompField = this->m_pContext->m_picLayerHeader->INTCOMFIELD;
             if (this->m_pContext->m_seqLayerHeader.PROFILE == VC1_PROFILE_ADVANCED)
             {
                 PicHeaderSize = (this->m_pPacker.VC1GetPicHeaderSize(p_CurOriginalData + 4,
@@ -1313,7 +1311,6 @@ namespace UMC
                     this->m_pContext->m_picLayerHeader->is_slice = 0;
                     DecodePicHeader(this->m_pContext);
 
-                    //this->m_pContext->this->m_picLayerHeader->INTCOMFIELD = IntCompField;
                     PicHeaderSize = (uint32_t)this->m_pPacker.VC1GetPicHeaderSize(p_CurOriginalData + 4 + *p_CurOriginalOffsets,
                         (uint32_t)((size_t)sizeof(uint32_t)*(this->m_pContext->m_bitstream.pBitstream - pPictHeader)), Flag_03);
 
