@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2018 Intel Corporation
+// Copyright (c) 2017-2019 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -139,7 +139,6 @@ namespace UMC
             lut_bitplane[1] = &pContext->m_picLayerHeader->SKIPMB;
             lut_bitplane[2] = &pContext->m_picLayerHeader->FORWARDMB;
             break;
-        case VC1_SKIPPED_FRAME:
         default:
             return;
         }
@@ -469,8 +468,6 @@ namespace UMC
             lut_bitplane[1] = &pContext->m_picLayerHeader->SKIPMB;
             lut_bitplane[2] = &pContext->m_picLayerHeader->FORWARDMB;
             break;
-        case VC1_SKIPPED_FRAME:
-            return;
         default:
             return;
         }
@@ -535,13 +532,14 @@ namespace UMC
         ptr->transform_fields.bits.transform_ac_codingset_idx2 = pContext->m_picLayerHeader->TRANSACFRM2;
         ptr->transform_fields.bits.intra_transform_dc_table = pContext->m_picLayerHeader->TRANSDCTAB;
 
-        switch (pContext->m_picLayerHeader->PTYPE)
+        if (pContext->m_picLayerHeader->PTYPE == VC1_B_FRAME)
         {
-        case VC1_B_FRAME:
             ptr->backward_reference_picture = va->GetSurfaceID(pContext->m_frmBuff.m_iNextIndex);
-        case VC1_P_FRAME:
             ptr->forward_reference_picture =  va->GetSurfaceID(pContext->m_frmBuff.m_iPrevIndex);
-            break;
+        }
+        else if (pContext->m_picLayerHeader->PTYPE == VC1_P_FRAME)
+        {
+            ptr->forward_reference_picture =  va->GetSurfaceID(pContext->m_frmBuff.m_iPrevIndex);
         }
     }
     void  VC1PackerLVA::VC1PackOneSlice (VC1Context* /*pContext*/,
