@@ -128,7 +128,7 @@ void CResourcesPool::CloseAndDeleteEverything()
 mfxStatus CRegionEncodingPipeline::InitMfxEncParams(sInputParams *pInParams)
 {
     CEncodingPipeline::InitMfxEncParams(pInParams);
-    m_mfxEncParams.mfx.TargetKbps              = pInParams->nBitRate / pInParams->nNumSlice; // in Kbps
+    m_mfxEncParams.mfx.TargetKbps = (mfxU16)pInParams->nBitRate / pInParams->nNumSlice; // in Kbps
 
     if (m_mfxEncParams.mfx.NumSlice > 1 && MFX_CODEC_HEVC == pInParams->CodecId)
     {
@@ -384,12 +384,10 @@ mfxStatus CRegionEncodingPipeline::Init(sInputParams *pParams)
         }
         else
         {
-            bool isDefaultPlugin = false;
             if (AreGuidsEqual(pParams->pluginParams.pluginGuid, MSDK_PLUGINGUID_NULL))
             {
                 mfxIMPL impl = pParams->bUseHWLib ? MFX_IMPL_HARDWARE : MFX_IMPL_SOFTWARE;
                 pParams->pluginParams.pluginGuid = msdkGetPluginUID(impl, MSDK_VENCODE, pParams->CodecId);
-                isDefaultPlugin = true;
             }
             if (!AreGuidsEqual(pParams->pluginParams.pluginGuid, MSDK_PLUGINGUID_NULL))
             {
