@@ -71,9 +71,9 @@ void PrintHelp(msdk_char *strAppName, const msdk_char *strErrorMessage, ...)
     msdk_printf(MSDK_STRING("   [-dGfx] - preffer processing on dGfx (by default system decides)\n"));
     msdk_printf(MSDK_STRING("   [-iGfx] - preffer processing on iGfx (by default system decides)\n"));
 #endif
-    msdk_printf(MSDK_STRING("   [-nv12|yuy2|uyvy|ayuv|rgb4|p010|y210|y410|a2rgb10] - input color format (by default YUV420 is expected).\n"));
+    msdk_printf(MSDK_STRING("   [-nv12|nv16|yuy2|uyvy|ayuv|rgb4|p010|y210|y410|a2rgb10|p016|p210|y216] - input color format (by default YUV420 is expected).\n"));
     msdk_printf(MSDK_STRING("   [-msb10] - 10-bit color format is expected to have data in Most Significant Bits of words.\n                 (LSB data placement is expected by default).\n                 This option also disables data shifting during file reading.\n"));
-    msdk_printf(MSDK_STRING("   [-ec::p010] - force usage of P010 surfaces for encoder (conversion will be made if necessary). Use for 10 bit HEVC encoding\n"));
+    msdk_printf(MSDK_STRING("   [-ec::p010|yuy2|nv12|nv16|rgb4|ayuv|uyvy|y210|y410|p016|y216] - force output color format for encoder (conversion will be made if necessary). Default value: input color format\n"));
     msdk_printf(MSDK_STRING("   [-tff|bff] - input stream is interlaced, top|bottom fielf first, if not specified progressive is expected\n"));
     msdk_printf(MSDK_STRING("   [-bref] - arrange B frames in B pyramid reference structure\n"));
     msdk_printf(MSDK_STRING("   [-nobref] -  do not use B-pyramid (by default the decision is made by library)\n"));
@@ -90,9 +90,14 @@ void PrintHelp(msdk_char *strAppName, const msdk_char *strErrorMessage, ...)
     msdk_printf(MSDK_STRING("   [-num_active_P numRefs]   - number of maximum allowed references for P frames (for HEVC only)\n"));
     msdk_printf(MSDK_STRING("   [-num_active_BL0 numRefs] - number of maximum allowed references for B frames in L0 (for HEVC only)\n"));
     msdk_printf(MSDK_STRING("   [-num_active_BL1 numRefs] - number of maximum allowed references for B frames in L1 (for HEVC only)\n"));
+#if (MFX_VERSION >= 1027)
+    msdk_printf(MSDK_STRING("   [-TargetBitDepthLuma] - Encoding target bit depth for luma samples, by default same as source one \n"));
+    msdk_printf(MSDK_STRING("   [-TargetBitDepthChroma] - Encoding target bit depth for chroma samples, by default same as source one \n"));
+#endif
     msdk_printf(MSDK_STRING("   [-la] - use the look ahead bitrate control algorithm (LA BRC) (by default constant bitrate control method is used)\n"));
     msdk_printf(MSDK_STRING("           for H.264, H.265 encoder. Supported only with -hw option on 4th Generation Intel Core processors. \n"));
     msdk_printf(MSDK_STRING("           if [-icq] option is also enabled simultaneously, then LA_ICQ bitrate control algotithm will be used. \n"));
+    msdk_printf(MSDK_STRING("   [-la_ext] - use external LA plugin (compatible with H.264, H.265 encoders)\n"));
     msdk_printf(MSDK_STRING("   [-lad depth] - depth parameter for the LA BRC, the number of frames to be analyzed before encoding. In range [0,100] (0 - default: auto-select by mediasdk library).\n"));
     msdk_printf(MSDK_STRING("            may be 1 in the case when -mss option is specified \n"));
     msdk_printf(MSDK_STRING("            if [-icq] option is also enabled simultaneously, then LA_ICQ bitrate control algotithm will be used. \n"));
@@ -108,6 +113,7 @@ void PrintHelp(msdk_char *strAppName, const msdk_char *strErrorMessage, ...)
     msdk_printf(MSDK_STRING("   [-robust:soft]           - Recovery from GPU hang by inserting an IDR\n"));
     msdk_printf(MSDK_STRING("   [-vbr]                   - variable bitrate control\n"));
     msdk_printf(MSDK_STRING("   [-cbr]                   - constant bitrate control\n"));
+    msdk_printf(MSDK_STRING("   [-vcm]                   - Video Conferencing Mode (VCM) bitrate control method\n"));
     msdk_printf(MSDK_STRING("   [-qvbr quality]          - variable bitrate control algorithm with constant quality. Quality in range [1,51]. 1 is the best quality.\n"));
     msdk_printf(MSDK_STRING("   [-icq quality]           - Intelligent Constant Quality (ICQ) bitrate control method. In range [1,51]. 1 is the best quality.\n"));
     msdk_printf(MSDK_STRING("                              If [-la] or [-lad] options are enabled simultaneously, then LA_ICQ bitrate control method will be used.\n"));
@@ -167,10 +173,12 @@ void PrintHelp(msdk_char *strAppName, const msdk_char *strErrorMessage, ...)
     msdk_printf(MSDK_STRING("   [-WeightedPred:default|implicit ]   - enables weighted prediction mode\n"));
     msdk_printf(MSDK_STRING("   [-WeightedBiPred:default|implicit ] - enables weighted bi-prediction mode\n"));
     msdk_printf(MSDK_STRING("   [-timeout]               - encoding in cycle not less than specific time in seconds\n"));
-    msdk_printf(MSDK_STRING("   [-perf_opt n]            - sets number of prefetched frames. In performance mode app preallocates buffer and load first n frames\n"));
+    msdk_printf(MSDK_STRING("   [-perf_opt n]            - sets number of prefetched frames. In performance mode app preallocates buffer and loads first n frames\n"));
+    msdk_printf(MSDK_STRING("   [-fps]                   - limits overall fps of pipeline\n"));
     msdk_printf(MSDK_STRING("   [-uncut]                 - do not cut output file in looped mode (in case of -timeout option)\n"));
     msdk_printf(MSDK_STRING("   [-dump fileName]         - dump MSDK components configuration to the file in text form\n"));
     msdk_printf(MSDK_STRING("   [-qpfile <filepath>]     - if specified, the encoder will take frame parameters (frame number, QP, frame type) from text file\n"));
+    msdk_printf(MSDK_STRING("   [-tcbrctestfile <filepath>] - if specified, the encoder will take targetFrameSize parameters for TCBRC test from text file\n"));
     msdk_printf(MSDK_STRING("   [-usei]                  - insert user data unregistered SEI. eg: 7fc92488825d11e7bb31be2e44b06b34:0:MSDK (uuid:type<0-preifx/1-suffix>:message)\n"));
     msdk_printf(MSDK_STRING("                              the suffix SEI for HEVCe can be inserted when CQP used or HRD disabled\n"));
 #if (MFX_VERSION >= MFX_VERSION_NEXT)
@@ -186,6 +194,7 @@ void PrintHelp(msdk_char *strAppName, const msdk_char *strErrorMessage, ...)
     msdk_printf(MSDK_STRING("Example: %s h265 -i InputYUVFile -o OutputEncodedFile -w width -h height -hw -p 2fca99749fdb49aeb121a5b63ef568f7\n"), strAppName);
     msdk_printf(MSDK_STRING("   [-preset <default,dss,conference,gaming>] - Use particular preset for encoding parameters\n"));
     msdk_printf(MSDK_STRING("   [-pp] - Print preset parameters\n"));
+    msdk_printf(MSDK_STRING("   [-sys] - work with linear buffer in system memory\n"));
 #if D3D_SURFACES_SUPPORT
     msdk_printf(MSDK_STRING("   [-d3d] - work with d3d surfaces\n"));
     msdk_printf(MSDK_STRING("   [-d3d11] - work with d3d11 surfaces\n"));
@@ -227,14 +236,31 @@ mfxStatus ParseAdditionalParams(msdk_char *strInput[], mfxU8 nArgNum, mfxU8& i,
         pParams->nAvcTemp = 1;
         VAL_CHECK(i + 1 >= nArgNum, i, strInput[i]);
         mfxU16 arr[8] = { 0,0,0,0,0,0,0,0 };
-        int j, k;
-        k = msdk_sscanf(strInput[i + 1], MSDK_STRING("%hu %hu %hu %hu %hu %hu %hu %hu"), &arr[0], &arr[1], &arr[2], &arr[3], &arr[4], &arr[5], &arr[6], &arr[7]);
+        int j;
+        msdk_sscanf(strInput[i + 1], MSDK_STRING("%hu %hu %hu %hu %hu %hu %hu %hu"), &arr[0], &arr[1], &arr[2], &arr[3], &arr[4], &arr[5], &arr[6], &arr[7]);
         for (j = 0; j < 8; j++)
         {
             pParams->nAvcTemporalLayers[j] = arr[j];
         }
         i += 1;
     }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-u")))
+    {
+        VAL_CHECK(i + 1 >= nArgNum, i, strInput[i]);
+        pParams->nTargetUsage = StrToTargetUsage(strInput[++i]);
+        if (!pParams->nTargetUsage)
+        {
+            msdk_printf(MSDK_STRING("error: wrong '-u' parameter. Balanced will be used.\n"));
+            pParams->nTargetUsage = MFX_TARGETUSAGE_BALANCED;
+        }
+    }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-tcbrctestfile")))
+    {
+        VAL_CHECK(i + 1 >= nArgNum, i, strInput[i]);
+        pParams->TCBRCFileMode = true;
+        pParams->strTCBRCFilePath = strInput[++i];
+        i += 1;
+    }
 
     else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-BaseLayerPID")))
     {
@@ -288,6 +314,109 @@ mfxStatus ParseAdditionalParams(msdk_char *strInput[], mfxU8 nArgNum, mfxU8& i,
     {
         pParams->nVuiNalHrdParameters = MFX_CODINGOPTION_OFF;
     }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-la_ext")))
+    {
+        pParams->bEnableExtLA            = true;
+        pParams->nRateControlMethod      = MFX_RATECONTROL_LA_EXT;
+    }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-vcm")))
+    {
+        pParams->nRateControlMethod = MFX_RATECONTROL_VCM;
+    }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-p210")))
+    {
+        pParams->FileInputFourCC = MFX_FOURCC_P210;
+    }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-nv16")))
+    {
+        pParams->FileInputFourCC = MFX_FOURCC_NV16;
+    }
+#if (MFX_VERSION >= 1031)
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-p016")))
+    {
+        pParams->FileInputFourCC = MFX_FOURCC_P016;
+    }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-y216")))
+    {
+        pParams->FileInputFourCC = MFX_FOURCC_Y216;
+    }
+#endif
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-ec::yuy2")))
+    {
+        pParams->EncodeFourCC = MFX_FOURCC_YUY2;
+    }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-ec::nv12")))
+    {
+        pParams->EncodeFourCC = MFX_FOURCC_NV12;
+    }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-ec::rgb4")))
+    {
+        pParams->EncodeFourCC = MFX_FOURCC_RGB4;
+    }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-ec::ayuv")))
+    {
+        pParams->EncodeFourCC = MFX_FOURCC_AYUV;
+    }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-ec::uyvy")))
+    {
+        pParams->EncodeFourCC = MFX_FOURCC_UYVY;
+    }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-ec::nv16")))
+    {
+        pParams->EncodeFourCC = MFX_FOURCC_NV16;
+    }
+#if (MFX_VERSION >= 1027)
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-ec::y210")))
+    {
+        pParams->EncodeFourCC = MFX_FOURCC_Y210;
+    }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-ec::y410")))
+    {
+        pParams->EncodeFourCC = MFX_FOURCC_Y410;
+    }
+#endif
+#if (MFX_VERSION >= 1031)
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-ec::p016")))
+    {
+        pParams->EncodeFourCC = MFX_FOURCC_P016;
+    }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-ec::y216")))
+    {
+        pParams->EncodeFourCC = MFX_FOURCC_Y216;
+    }
+#endif
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-fps")))
+    {
+        VAL_CHECK(i+1 >= nArgNum, i, strInput[i]);
+
+        if (MFX_ERR_NONE != msdk_opt_read(strInput[++i], pParams->nMaxFPS))
+        {
+            PrintHelp(strInput[0], MSDK_STRING("overall fps is invalid"));
+            return MFX_ERR_UNSUPPORTED;
+        }
+	}
+#if (MFX_VERSION >= 1027)
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-TargetBitDepthLuma")))
+    {
+        VAL_CHECK(i + 1 >= nArgNum, i, strInput[i]);
+
+        if (MFX_ERR_NONE != msdk_opt_read(strInput[++i], pParams->TargetBitDepthLuma))
+        {
+            PrintHelp(strInput[0], MSDK_STRING("TargetBitDepthLuma is invalid"));
+            return MFX_ERR_UNSUPPORTED;
+        }
+    }
+    else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-TargetBitDepthChroma")))
+    {
+        VAL_CHECK(i + 1 >= nArgNum, i, strInput[i]);
+
+        if (MFX_ERR_NONE != msdk_opt_read(strInput[++i], pParams->TargetBitDepthChroma))
+        {
+            PrintHelp(strInput[0], MSDK_STRING("TargetBitDepthChroma is invalid"));
+            return MFX_ERR_UNSUPPORTED;
+        }
+    }
+#endif
     else
     {
         return MFX_ERR_NOT_FOUND;
@@ -313,9 +442,10 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
     pParams->isV4L2InputEnabled = false;
     pParams->nNumFrames = 0;
     pParams->FileInputFourCC = MFX_FOURCC_I420;
-    pParams->EncodeFourCC = MFX_FOURCC_NV12;
+    pParams->EncodeFourCC = 0;
     pParams->nPRefType = MFX_P_REF_DEFAULT;
     pParams->QPFileMode = false;
+    pParams->TCBRCFileMode = false;
     pParams->BitrateLimit = MFX_CODINGOPTION_OFF;
 #if (MFX_VERSION >= 1027)
     pParams->RoundingOffsetFile = NULL;
@@ -422,7 +552,6 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-yuy2")))
         {
             pParams->FileInputFourCC = MFX_FOURCC_YUY2;
-            pParams->EncodeFourCC = MFX_FOURCC_YUY2;
         }
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-nv12")))
         {
@@ -431,40 +560,32 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-rgb4")))
         {
             pParams->FileInputFourCC = MFX_FOURCC_RGB4;
-            pParams->EncodeFourCC = MFX_FOURCC_RGB4;
         }
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-p010")))
         {
             pParams->FileInputFourCC = MFX_FOURCC_P010;
-            pParams->EncodeFourCC = MFX_FOURCC_P010;
         }
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-ayuv")))
         {
             pParams->FileInputFourCC = MFX_FOURCC_AYUV;
-            pParams->EncodeFourCC = MFX_FOURCC_AYUV;
         }
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-uyvy")))
         {
             pParams->FileInputFourCC = MFX_FOURCC_UYVY;
-            // use YUY2 to get chroma subsampling 4:2:2 in encoded image
-            pParams->EncodeFourCC = MFX_FOURCC_YUY2;
         }
 #if (MFX_VERSION >= 1027)
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-y210")))
         {
             pParams->FileInputFourCC = MFX_FOURCC_Y210;
-            pParams->EncodeFourCC = MFX_FOURCC_Y210;
         }
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-y410")))
         {
             pParams->FileInputFourCC = MFX_FOURCC_Y410;
-            pParams->EncodeFourCC = MFX_FOURCC_Y410;
         }
 #endif
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-a2rgb10")))
         {
             pParams->FileInputFourCC = MFX_FOURCC_A2RGB10;
-            pParams->EncodeFourCC = MFX_FOURCC_A2RGB10;
         }
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-ec::p010")))
         {
@@ -488,6 +609,7 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
         }
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-idr_interval")))
         {
+            VAL_CHECK(i + 1 >= nArgNum, i, strInput[i]);
             if (MFX_ERR_NONE != msdk_opt_read(strInput[++i], pParams->nIdrInterval))
             {
                 PrintHelp(strInput[0], MSDK_STRING("IdrInterval is invalid"));
@@ -550,7 +672,8 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
                 pParams->nRateControlMethod = MFX_RATECONTROL_LA_ICQ;
             }
             else if (pParams->nRateControlMethod != MFX_RATECONTROL_LA &&
-                    pParams->nRateControlMethod != MFX_RATECONTROL_LA_ICQ)
+                    pParams->nRateControlMethod != MFX_RATECONTROL_LA_ICQ &&
+                    pParams->nRateControlMethod != MFX_RATECONTROL_LA_EXT)
             {
                 PrintHelp(strInput[0], MSDK_STRING("More than one BRC modes assigned, and another BRC mode isn't compatible with LA."));
                 return MFX_ERR_UNSUPPORTED;
@@ -640,7 +763,10 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
             pParams->QPFileMode = true;
             pParams->strQPFilePath = strInput[++i];
         }
-
+        else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-sys")))
+        {
+            pParams->memType = SYSTEM_MEMORY;
+        }
 #if D3D_SURFACES_SUPPORT
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-d3d")))
         {
@@ -654,7 +780,7 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
 #ifdef LIBVA_SUPPORT
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-vaapi")))
         {
-            pParams->memType = D3D9_MEMORY;
+            pParams->memType = VAAPI_MEMORY;
         }
 #endif
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-async")))
@@ -1186,6 +1312,7 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
         }
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-p")))
         {
+            VAL_CHECK(i + 1 >= nArgNum, i, strInput[i]);
             pParams->pluginParams = ParsePluginGuid(strInput[++i]);
             if (AreGuidsEqual(pParams->pluginParams.pluginGuid, MSDK_PLUGINGUID_NULL))
             {
@@ -1209,6 +1336,7 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
         }
         else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-path")))
         {
+            VAL_CHECK(i + 1 >= nArgNum, i, strInput[i]);
             i++;
             pParams->pluginParams = ParsePluginPath(strInput[i]);
         }
@@ -1269,16 +1397,6 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
             pParams->isV4L2InputEnabled = true;
         }
 #endif
-        else if (0 == msdk_strcmp(strInput[i], MSDK_STRING("-u")))
-        {
-            VAL_CHECK(i + 1 >= nArgNum, i, strInput[i]);
-            pParams->nTargetUsage = StrToTargetUsage(strInput[++i]);
-            if (!pParams->nTargetUsage)
-            {
-                msdk_printf(MSDK_STRING("error: wrong '-u' parameter. Balanced will be used.\n"));
-                pParams->nTargetUsage = MFX_TARGETUSAGE_BALANCED;
-            }
-        }
         else
         {
             mfxStatus sts = ParseAdditionalParams(strInput, nArgNum, i, pParams);
@@ -1291,6 +1409,16 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
         }
     }
 
+    if(!pParams->memType) {
+        pParams->memType = pParams->bUseHWLib ?
+#if defined(_WIN32) || defined(_WIN64)
+        D3D11_MEMORY
+#else
+        VAAPI_MEMORY
+#endif
+        : SYSTEM_MEMORY;
+    }
+
 #if defined (ENABLE_V4L2_SUPPORT)
     if (pParams->isV4L2InputEnabled)
     {
@@ -1339,8 +1467,19 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
         return MFX_ERR_UNSUPPORTED;
     }
 
+    if (!pParams->EncodeFourCC)
+    {
+        if (pParams->FileInputFourCC == MFX_FOURCC_UYVY)
+            // use YUY2 to get chroma subsampling 4:2:2 in encoded image
+            pParams->EncodeFourCC = MFX_FOURCC_YUY2;
+        else if (pParams->FileInputFourCC == MFX_FOURCC_I420)
+            pParams->EncodeFourCC = MFX_FOURCC_NV12;
+        else
+            pParams->EncodeFourCC = pParams->FileInputFourCC;
+    }
+
     if (MFX_CODEC_JPEG != pParams->CodecId && MFX_CODEC_HEVC != pParams->CodecId &&
-        pParams->FileInputFourCC == MFX_FOURCC_YUY2 &&
+        pParams->EncodeFourCC == MFX_FOURCC_YUY2 &&
         !pParams->isV4L2InputEnabled)
     {
         PrintHelp(strInput[0], MSDK_STRING("-yuy2 option is supported only for JPEG or HEVC encoder"));
@@ -1444,11 +1583,12 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
         return MFX_ERR_UNSUPPORTED;
     }
 
-    //if ((pParams->nRateControlMethod == MFX_RATECONTROL_LA) && (pParams->CodecId != MFX_CODEC_AVC))
-    //{
-    //    PrintHelp(strInput[0], MSDK_STRING("Look ahead BRC is supported only with H.264 encoder!"));
-    //    return MFX_ERR_UNSUPPORTED;
-    //}
+    if (pParams->nRateControlMethod == MFX_RATECONTROL_LA  &&
+        pParams->CodecId == MFX_CODEC_HEVC)
+    {
+        pParams->bEnableExtLA            = true;
+        pParams->nRateControlMethod      = MFX_RATECONTROL_LA_EXT;
+    }
 
     if ((pParams->nMaxSliceSize) && (pParams->CodecId != MFX_CODEC_AVC) && (pParams->CodecId != MFX_CODEC_HEVC))
     {
@@ -1522,6 +1662,34 @@ mfxStatus ParseInputString(msdk_char* strInput[], mfxU8 nArgNum, sInputParams* p
     }
 #endif
 
+    mfxU16 mfxU16Limit = std::numeric_limits<mfxU16>::max();
+    if (pParams->MaxKbps > mfxU16Limit || pParams->nBitRate > mfxU16Limit ||
+        pParams->InitialDelayInKB > mfxU16Limit || pParams->BufferSizeInKB > mfxU16Limit)
+    {
+        mfxU32 maxVal = std::max<mfxU32>({ pParams->MaxKbps,
+                                           pParams->nBitRate,
+                                           pParams->InitialDelayInKB,
+                                           pParams->BufferSizeInKB });
+        pParams->nBitRateMultiplier = (mfxU16)std::ceil(static_cast<double>(maxVal) / mfxU16Limit);
+        msdk_printf(MSDK_STRING("WARNING: BitRateMultiplier(-bm) was updated, new value - %d. \n"), pParams->nBitRateMultiplier);
+
+        auto recalculate = [mfxU16Limit, pParams] (mfxU32 &param, msdk_string paramName)
+        { 
+            if (param)
+            {
+                if (param > mfxU16Limit)
+                    msdk_printf(MSDK_STRING("WARNING: %s (%d) > allow limit (%d). \n"), paramName.c_str(), param, mfxU16Limit);
+                param = param / pParams->nBitRateMultiplier;
+                msdk_printf(MSDK_STRING("WARNING: %s was updated, new value: %d. \n"), paramName.c_str(), param);
+            }
+        };
+
+        recalculate(pParams->MaxKbps, MSDK_STRING("MaxKbps"));
+        recalculate(pParams->nBitRate, MSDK_STRING("nBitRate(-b)"));
+        recalculate(pParams->InitialDelayInKB, MSDK_STRING("InitialDelayInKB"));
+        recalculate(pParams->BufferSizeInKB, MSDK_STRING("BufferSizeInKB"));
+    }
+
     return MFX_ERR_NONE;
 }
 
@@ -1529,14 +1697,6 @@ void ModifyParamsUsingPresets(sInputParams& params)
 {
     COutputPresetParameters presetParams = CPresetManager::Inst.GetPreset(params.PresetMode, params.CodecId,params.dFrameRate, params.nWidth, params.nHeight, params.bUseHWLib);
 
-    if (presetParams.RateControlMethod == MFX_RATECONTROL_LA_EXT)
-    {
-        // Currently sample_encode does not support external LA, so we will use ExtBRC instead
-        presetParams.RateControlMethod = MFX_RATECONTROL_VBR;
-        presetParams.LookAheadDepth = 0;
-        presetParams.ExtBRCUsage = EXTBRC_ON;
-    }
-
     if (params.shouldPrintPresets)
     {
         msdk_printf(MSDK_STRING("Preset-controlled parameters (%s):\n"), presetParams.PresetName.c_str());
@@ -1566,7 +1726,7 @@ void ModifyParamsUsingPresets(sInputParams& params)
     {
         MODIFY_AND_PRINT_PARAM(params.nBitRate, TargetKbps, params.shouldPrintPresets);
         MODIFY_AND_PRINT_PARAM(params.MaxKbps, MaxKbps, params.shouldPrintPresets);
-        presetParams.BufferSizeInKB = params.nBitRate; // Update bitrate to reflect manually set bitrate. BufferSize should be enough for 1 second of video
+        presetParams.BufferSizeInKB = (mfxU16)params.nBitRate / 8; // Update bitrate to reflect manually set bitrate. BufferSize should be enough for 1 second of video
         MODIFY_AND_PRINT_PARAM(params.BufferSizeInKB, BufferSizeInKB, params.shouldPrintPresets);
     }
 
