@@ -256,7 +256,7 @@ void PrintInfo(sInputParams* pParams, mfxVideoParam* pMfxParams, MFXVideoSession
     //-------------------------------------------------------
     mfxIMPL impl;
     pMfxSession->QueryIMPL(&impl);
-    bool isHWlib = (MFX_IMPL_HARDWARE & impl) ? true:false;
+    bool isHWlib = (MFX_IMPL_SOFTWARE != impl) ? true:false;
 
     const msdk_char* sImpl = (isHWlib) ? MSDK_STRING("hw") : MSDK_STRING("sw");
     msdk_printf(MSDK_STRING("MediaSDK impl\t%s"), sImpl);
@@ -1962,6 +1962,15 @@ mfxStatus CRawVideoWriter::WriteFrame(
             MSDK_CHECK_NOT_EQUAL( fwrite(ptr+ i * pitch, 1, 2*w, m_fDst), 2u*w, MFX_ERR_UNDEFINED_BEHAVIOR);
         }
     }
+    else if( pInfo->FourCC == MFX_FOURCC_UYVY )
+    {
+        ptr = pData->U + pInfo->CropX + pInfo->CropY * pitch;
+
+        for(i = 0; i < h; i++)
+        {
+            MSDK_CHECK_NOT_EQUAL( fwrite(ptr+ i * pitch, 1, 2*w, m_fDst), 2u*w, MFX_ERR_UNDEFINED_BEHAVIOR);
+        }
+    }
     else if ( pInfo->FourCC == MFX_FOURCC_IMC3 )
     {
         ptr   = pData->Y + (pInfo->CropX ) + (pInfo->CropY ) * pitch;
